@@ -117,6 +117,9 @@ public:
    */
   void set_self_hosted(const std::string& data_uri);
 
+  /** Creates a new database.
+   */
+  void create_database(const Glib::ustring& database_name);
 
   void set_host(const Glib::ustring& value);
   void set_user(const Glib::ustring& value);
@@ -124,6 +127,7 @@ public:
   void set_database(const Glib::ustring& value);
 
   Glib::ustring get_host() const;
+  //Glib::ustring get_port() const;
   Glib::ustring get_user() const;
   Glib::ustring get_password() const;
   Glib::ustring get_database() const;
@@ -146,8 +150,9 @@ public:
   void stop_self_hosting();
 
   /** Create new database files, for later use by their own  database server instance.
+   * @param parent_window A parent window to use as the transient window when displaying errors.
    */
-  bool create_self_hosting();
+  bool create_self_hosting(Gtk::Window* parent_window);
 
   //Show the gda error in a dialog.
   static bool handle_error(bool cerr_only = false);
@@ -165,6 +170,14 @@ public:
    */
   static bool install_postgres(Gtk::Window* parent_window);
 
+  /** Check whether the libgda postgres provider is really available, 
+   * so we can connect to postgres servers,
+   * in case the distro package has incorrect dependencies.
+   *
+   * @results True if everything is OK.
+   */
+  static bool check_postgres_gda_client_is_available_with_warning();
+
 protected:
   void on_sharedconnection_finished();
 
@@ -182,7 +195,8 @@ protected:
 
 protected:
 
-  bool directory_exists(const std::string& uri);
+  //bool directory_exists_filepath(const std::string& filepath);
+  bool directory_exists_uri(const std::string& uri);
 
   typedef std::list<Glib::ustring> type_list_ports;
   type_list_ports m_list_ports; //Network ports on which to try connecting to postgres.
