@@ -23,12 +23,15 @@
 
 #include <gtkmm.h>
 #include "../utility_widgets/dialog_properties.h"
-#include "../document/document_glom.h"
+#include <glom/libglom/document/document_glom.h>
 #include "../box_db.h"
 #include "../utility_widgets/combo_textglade.h"
 #include "../combobox_relationship.h"
 #include "../utility_widgets/comboentry_currency.h"
 
+namespace Glom
+{
+
 class Dialog_ChooseField : public Gtk::Dialog
 {
 public:
@@ -81,4 +84,6 @@ protected:
   Document_Glom* m_document;
 };
 
+} //namespace Glom
+
 #endif //GLOM_MODE_DATA_DIALOG_CHOOSE_FIELD_H
